from django.db.models.query_utils import Q

import graphene
from graphene_django import DjangoObjectType

from aleksis.core.schema.base import DjangoFilterMixin, FilterOrderList

from ..models import Documentation, Participation
from .documentation import (
    DocumentationBatchCreateMutation,
    DocumentationBatchPatchMutation,
    DocumentationCreateMutation,
    DocumentationDeleteMutation,
    DocumentationType,
)


class Query(graphene.ObjectType):
    documentations = FilterOrderList(DocumentationType)
    documentations_by_course_id = FilterOrderList(
        DocumentationType, course_id=graphene.ID(required=True)
    )

    def resolve_documentations_by_course_id(root, info, course_id, **kwargs):
        documentations = Documentation.objects.filter(
            Q(course__pk=course_id) | Q(lesson_event__course__pk=course_id)
        )
        return documentations


class Mutation(graphene.ObjectType):
    create_documentation = DocumentationCreateMutation.Field()
    create_documentations = DocumentationBatchCreateMutation.Field()
    delete_documentation = DocumentationDeleteMutation.Field()
    update_documentations = DocumentationBatchPatchMutation.Field()
